#
# spec file for package python-zict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-zict
Version:        3.0.0
Release:        3.2
Summary:        Mutable mapping tools
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/dask/zict/
Source:         https://files.pythonhosted.org/packages/source/z/zict/zict-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
#BuildRequires:  %%{python_module lmdb}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Mutable Mapping interfaces for python.

%prep
%setup -q -n zict-%{version}
# needs more memory than what we have on generic hosts
rm zict/tests/test_lmdb.py
# ignore pytest-repeat marker: we don't stress test on OBS
sed -i '/markers =/ a \    repeat: Ignore me' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/zict
%{python_sitelib}/zict-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Ben Greiner <code@bnavigator.de>
- Remove lmdb test requirement: the tests have been disabled anyway
* Wed Aug 14 2024 Dirk Müller <dmueller@suse.com>
- switch to modern python for sle15
* Sun Sep 10 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
  * The library is now almost completely thread-safe (#82, #90,
    [#92], #93)
  * Dropped support for Python 3.7 (#84)
  * File.__getitem__ now returns bytearray instead of bytes. This
    prevents a memcpy when deserializing numpy arrays with dask.
    (#74)
  * Removed dependency from heapdict; sped up LRU (#77)
  * Fixed broken LRU state when the underlying mapping starts
    non-empty. (#77)
  * File and LMDB now support pathlib.Path and pytest’s tmpdir
    (#78)
  * LMDB now uses memory-mapped I/O on MacOSX and is usable on
    Windows (#78)
  * LRU and Buffer now support delayed eviction (#87)
  * New object InsertionSortedSet (#87)
  * All mappings now return proper KeysView, ItemsView, and
    ValuesView objects from their keys(), items(), and values()
    methods (#93)
  * File, LMDB, and Zip now behave coherently with unexpected
    key/value types (#95)
  * Zip.__contains__ no longer reads the value from disk (#95)
  * Zip.__setitem__ will now raise when updating an
    already-existing key instead of quietly corrupting the mapping
    (#95)
  * Can now change LRU.n on the fly. Added LRU.offset attribute.
    Added accessors to n and offset to Buffer. (#101)
  * New object AsyncBuffer; new method LRU.get_all_or_nothing()
    (#88)
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.2.0
  * New class zict.Cache (#65)
  * Add absolufy-imports to CI (#66)
  * Descope pickled outputs sooner (#64)
  * Type annotations (#62)
  * Add `python_requires` to `setup.py` (#60)
- version update to 2.1.0
  * Run `isort` to fix lint (#58)
  * Allow file `mmap`ing (#51)
  * Update `README` badges (#57)
  * Run `isort` and `pyupgrade` in CI (#56)
  * Drop Python 3.6; add 3.9 and 3.10; use pre-commit (#55)
  * LRU raises (#48)
  * Avoid deprecated `pytest.yield_fixture` usage (#50)
  * Update LICENSE.txt (#46)
  * Bump GHA setup-miniconda version (#41)
  * MNT Migrate to GitHub actions (#40)
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 2.0.0
  * Create CONTRIBUTING.md (:pr:`28`) Jacob Tomlinson
  * Import ABC from collections.abc instead of collections for Python 3.9 compatibility (:pr:`31`) Karthikeyan Singaravelan
  * Drop Python 2 / 3.5 and add Python 3.7 / 3.8 support (:pr:`34`) James Bourbeau
  * Duplicate keys fast slow (:pr:`32`) fjetter
  * Fix dask cuda worker's race condition failure (:pr:`33`) Pradipta Ghosh
  * Changed default lmdb encoding to utf-8 (:pr:`36`) Alex Davies
  * Add code linting and style check (:pr:`35`) James Bourbeau
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.0:
  * no upstream changelog
* Wed Mar 27 2019 pgajdos@suse.com
- version update to 0.1.4
  * Use collections.abc to avoid DeprecationWarning
  * DOC: Add classes missing from API documentation.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Mar  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * don't use python_module in requires
* Tue Oct 31 2017 arun@gmx.de
- update to version 0.1.3:
  * update travis.yml to track Python 3.6
  * evict returns key, value, and weight
  * Add LRU.evict method (#18)
  * add links to readme and setup.py
* Thu Jul 13 2017 toddrme2178@gmail.com
- Initial version
